/// <reference types="express" />
import * as express from 'express';
import { StaticModelT, ModelT } from '../core/model';
export declare abstract class CrudController<T extends ModelT<any>> {
    private staticModel;
    protected readonly modelName: string;
    constructor(staticModel: StaticModelT<T>, modelName: string, pluralName?: string, singularName?: string);
    private splitOnWords(name);
    private getSingularPath(name);
    private getPluralPath(name);
    private singularName;
    private pluralName;
    transformPathPart(part: string): string;
    transformQuery(req: express.Request, res: express.Response, query: Object): Promise<Object>;
    transformResult(req: express.Request, res: express.Response, result: T | null): Promise<T | null>;
    transformCreateQuery(req: express.Request, res: express.Response, query: Object): Promise<Object>;
    transformCreateResult(req: express.Request, res: express.Response, result: T): Promise<T>;
    create(req: express.Request, res: express.Response): Promise<void>;
    protected afterCreate(req: express.Request, res: express.Response, result: T): Promise<void>;
    find(req: express.Request, res: express.Response): Promise<void>;
    count(req: express.Request, res: express.Response): Promise<void>;
    get(req: express.Request, res: express.Response): Promise<void>;
    update(req: express.Request, res: express.Response): Promise<void>;
    destroy(req: express.Request, res: express.Response): Promise<void>;
}
